#!/bin/sh
#	Create the sorted CSV file in the form <protein>,<species>,<kingdom>,<length>
#	from the reduced Fasta dataset for all relevant TrEMBL releases.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2019/12/12 14:19:23 $
#-------------------------------------------------
echo "This will take many hours to execute as it has to produce a sorted list of"
echo "all proteins for each of the five releases.  On a fast machine, perhaps 30 hours."
echo

for VERSION in 7-01 13-01 15-07 18-02 21-03
do
	SEQFILE=${VERSION}_uniprot_trembl.dat.gz
	CSVFILE=${VERSION}_trembl_protein_index.csv
	CSVFILE_SORTED=${VERSION}_trembl_protein_index_sorted.csv

	if test ! -f $SEQFILE
	then
		echo "$SEQFILE not present."
		exit
	fi

	rm -f $CSVFILE
#
#		Note that CSVFILE appends here.
#
	zcat	$SEQFILE	| ./txtToSeq.pl | ./createProteinCSVFasta.pl	-csvfile $CSVFILE

	echo "$CSVFILE created."

	if test ! -f $CSVFILE_SORTED
	then
		if test ! -f $CSVFILE
		then
			echo "File $CSVFILE is missing.  Create it with ./2-prepareData.sh"
			exit
		fi
#
#		Sort the index on increasing length of protein sequence.
#
		sort -t"," --key=4 $CSVFILE -n -T $TEMPDIR | uniq -u				> $CSVFILE_SORTED
		rm -f $CSVFILE
	else
		echo "File $CSVFILE_SORTED already exists.  To recreate, delete it and rerun $0."
	fi
#
#	Finally, we will need the normaliser and the fast sequence comparator.
#
if test ! -f normalise
then
	cc -o normalise normalise.c
fi

if test ! -f fastSeqComparison
then
	cc -o fastSeqComparison fastSeqComparison.c
fi

echo "You may now continue with the processing stages, 3-xxxx.sh for each figure"
echo "Process them in order 3-fig3.sh, 3-fig4.sh ..."
