#!/bin/sh
#
#	Copyright Les Hatton, 2019-.
#	Released under the GNU GPL.
#
#	Test for homogeneous power-law in protein re-use using
#	necessary (R lm()) tests and sufficiency (Clauset et. al.).
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2019/06/12 23:44:57 $
#-------------------------------------------------
if test $# -ne 2
then
	echo "This script calculates necessary and sufficiency stats for various data collections."
	echo "Usage: $0 [version, e.g. 18-02] [ARCHAEA|BACTERIA|EURKARYOTA|VIRUSES|ALL]"
	exit
fi

VERSION=$1
KINGDOM=$2

DATDIR=./
DB=trembl

REPFILE=$DATDIR/${VERSION}_${DB}_protein_sharing.csv
REPLICAS=${KINGDOM}_${VERSION}_${DB}_protein_replicas_ccdf.dat

if test ! -f $REPFILE
then
	echo "File $REPFILE does not exist.  You will need to create it."
	exit
fi

if test ! -f $REPLICAS
then
	if test "$KINGDOM" = "ARCHAEA"
	then
		cat $REPFILE | grep ",ARCHAEA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
			| ./normalise ccdf            > $REPLICAS
	elif test "$KINGDOM" = "BACTERIA"
	then
		cat $REPFILE | grep ",BACTERIA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
			| ./normalise ccdf            > $REPLICAS
	elif test "$KINGDOM" = "EUKARYOTA"
	then
		cat $REPFILE | grep ",EUKARYOTA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
			| ./normalise ccdf            > $REPLICAS
	elif test "$KINGDOM" = "VIRUSES"
	then
		cat $REPFILE | grep ",VIRUSES:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
			| ./normalise ccdf            > $REPLICAS
	else
		cat $REPFILE |  awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
			| ./normalise ccdf            > $REPLICAS
	fi
fi
#
#	Necessary test.  Extract the x- and y- vectors.
#
CCDF="transfer_ccdf"
cat	$REPLICAS \
	| grep -v "^#" \
	| grep -v "^$" \
	| awk '{ if ( $2 > 1.0 ) print log($1);}'\
	> ${CCDF}_uni_x.txt
cat	$REPLICAS \
	| grep -v "^#" \
	| grep -v "^$" \
	| awk '{ if ( $2 > 1.0 ) print log($2);}'\
	> ${CCDF}_uni_y.txt

Rscript	powerlaw_necessary.R ${CCDF}_uni_x.txt ${CCDF}_uni_y.txt		> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
#
#	Sufficiency test.  Extract the x- and y- vectors.
#
cat	$REPLICAS \
	| grep -v "^#" \
	| grep -v "^$" \
	| awk '{print $1,$2;}' \
	> ${CCDF}_clauset.txt
FITRANGE=10000
#-------------------------------------------------
echo "=========================================="		>> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
echo `date`									>> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
echo "DAT $DAT"								>> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
echo "FITRANGE $FITRANGE"						>> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
Rscript	hgt_powerlaw_sufficiency.R				>> ${KINGDOM}_${VERSION}_${DB}_powerlawtests.txt
#-------------------------------------------------
