#!/bin/sh
#	Compare the domains of life with and without viruses.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2020/04/28 20:02:45 $
#-------------------------------------------------
VERSION=21-03
DB=trembl
DATDIR=./

if test ! -d $DATDIR
then
	echo "$DATDIR does not exist"
	exit
fi
#
#	Note that the REPLICAS file is created locally.
#
if test "$DB" = "trembl"
then
	CSVFILE=${VERSION}_${DB}_protein_index.csv
	CSVFILE_SORTED=${VERSION}_${DB}_protein_index_sorted.csv
	REPFILE=$DATDIR/${VERSION}_${DB}_protein_sharing.csv
	REPLICAS=${VERSION}_${DB}_protein_replicas_ccdf.dat
	RANALYSIS=$DATDIR/${VERSION}_${DB}_protein_replicas.out
elif test "$DB" = "swissprot"
then
	CSVFILE=${VERSION}_${DB}_protein_index.csv
	CSVFILE_SORTED=${VERSION}_${DB}_protein_index_sorted.csv
	REPFILE=$DATDIR/${VERSION}_${DB}_protein_sharing.csv
	REPLICAS=${VERSION}_${DB}_protein_replicas_ccdf.dat
	RANALYSIS=$DATDIR/${VERSION}_${DB}_protein_replicas.out
else
	echo "Unknown database source, $DB"
	exit
fi

COMBINED=${VERSION}_${DB}_protein_replicas_ccdf_lifenonlife.dat
rm -f $COMBINED

if test ! -f $CSVFILE_SORTED
then
	if test ! -f $CSVFILE
	then
		echo "File $CSVFILE is missing.  Create it with ./createProteinCSV.sh"
		exit
	fi
#
#	Sort the index on increasing length of protein sequence.
#
	sort -t"," --key=4 $CSVFILE -n | uniq -u				> $CSVFILE_SORTED
	rm -f $CSVFILE
else
	echo "File $CSVFILE_SORTED already exists.  To recreate, delete it and rerun $0."
fi
#
#	Find all the shared proteins.
#
#	Format is <length>,*-**** (number of kingdoms),<sequence>,<kingdom/species strings>,<count>,<protein name>
#
#	Create the whole thing.
#
if test ! -f $REPFILE
then
	./replicasInSpecies.pl -csvfile $CSVFILE_SORTED -repfile $REPFILE
else
	echo "File $REPFILE already exists.  To recreate, delete it and re-run $0."
fi
#
#	Create the ccdf for the replica occurrence.  We get rid of the first line with
#	tail because that count might be turned off in replicasInSpecies.pl.
#
#	Note that we include the zeroth value here.
#
#	We do this for the domains of life and then viruses.
#
#--------
cat $REPFILE | egrep ",ARCHAEA:|,BACTERIA:|,EUKARYOTA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cat $REPLICAS					>> $COMBINED
#--------
cat $REPFILE | egrep ",ARCHAEA:|,BACTERIA:|,EUKARYOTA:|VIRUSES:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cat $REPLICAS					>> $COMBINED

cat	protein_replicas_ccdf_lifenonlife.gnu	\
	| sed 's/VVVV/'"${VERSION}"'/g' \
	| sed 's/DDDD/'"${DB}"'/g' \
	| sed 's/TTTT/The domains of life and viruses/g'						> temp$$.gnu
gnuplot	temp$$.gnu

mv	${VERSION}_${DB}_protein_replicas_ccdf_lifenonlife.eps		Fig11.eps
convert	-density 300 Fig11.eps	Fig11.png
#--------
#
#	Clean up.
#
rm	-f temp$$.gnu
