#!/bin/sh
#	Make combined ccdf of different versions of trembl for reuse data.
#	Each graph is one domain of life or viruses shown combined for each
#	version.
#
#
#	We need to produce a .dat file of replica count for each domain and each version.
#-----------------------------------------------------------------------
mkdir	-p MULTIVERS

for domain in ARCHAEA BACTERIA EUKARYOTA VIRUSES ALL
do
	echo "Processing domain $domain"

	COMBODAT=${domain}_multivers_ccdf.dat
	rm	-f $COMBODAT
	COMBODATR=${domain}_multivers_rank.dat
	rm	-f $COMBODATR

	COMBOGNU=alldomains_multivers_ccdf.gnu
	COMBOGNUR=alldomains_multivers_rank.gnu
	rm	-f	temp$$.gnu

	for vers in 7-01 13-01 15-07 18-02 21-03
	do
		echo "... version $domain"

		CSVFILE=${vers}_trembl_protein_index_sorted.csv

		DATFILE=${vers}_trembl_protein_ccdf_${domain}.dat
		REPFILE=${vers}_trembl_protein_sharing.csv

		if test ! -f $REPFILE
		then
			if test ! -f $CSVFILE
			then
				echo "$CSVFILE does not exist.  This must be created by 2-prepareData.sh."
				exit
			else
				echo "Creating ... $REPFILE"
				./replicasInSpecies.pl	-csvfile $CSVFILE -repfile $REPFILE
			fi
		else
			echo "$REPFILE exists.  If this must be re-created simply rm it.  Continuing ..."
		fi

		if test "$domain" = "ALL"
		then
			pattern="."
		else
			pattern=",${domain}:"
		fi

		cat $REPFILE	\
			| egrep $pattern	\
			| awk '{FS=","}{print $5;}'	\
			| sort -n \
			| uniq -c \
			| tail -n +2 \
			| ./normalise ccdf				> $DATFILE

		cat	$DATFILE	>>	$COMBODAT
		echo			>>	$COMBODAT
	done
#
#	$DATFILE is by ccdf.  Also produce a rank-ordered one which removes the gaps
#	by removing the x-axis from the .dat file.
#
	cat	$COMBODAT		| awk '{if ( $1 != "#") {print $2;} else {print;}}'	> $COMBODATR
#
#	Produce a combo plot.
#
	cat	$COMBOGNU		\
		| sed 's/DDDD/'"${domain}"'/g' 	> temp$$.gnu
	gnuplot			temp$$.gnu
	cat	$COMBOGNUR		\
		| sed 's/DDDD/'"${domain}"'/g' 	> temp$$.gnu
	gnuplot			temp$$.gnu

	rm	-f	temp$$.gnu

	mv	$COMBODAT $COMBODATR		MULTIVERS

	convert	-density 300 ${domain}_multivers_ccdf.eps	${domain}_multivers_ccdf.png
	convert	-density 300 ${domain}_multivers_rank.eps	${domain}_multivers_rank.png
	mv	${domain}_multivers_ccdf.eps	MULTIVERS/${domain}_protein_replicas_multivers_ccdf.eps
	mv	${domain}_multivers_ccdf.png	MULTIVERS/${domain}_protein_replicas_multivers_ccdf.png
	mv	${domain}_multivers_rank.eps	MULTIVERS/${domain}_protein_replicas_multivers_rank.eps
	mv	${domain}_multivers_rank.png	MULTIVERS/${domain}_protein_replicas_multivers_rank.png
done

cp MULTIVERS/ALL_protein_replicas_multivers_ccdf.png	Fig4.png

echo "Other outputs in MULTIVERS/"
