#!/bin/sh
#	Create the ccdf for the occurrence of exact replicas.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2019/12/12 14:19:23 $
#-------------------------------------------------
VERSION=21-03
DB=trembl
#
#	NOTE!  You may have to point this somewhere else if your root partition
#	is quite small.
#
TMPDIR=/tmp

CSVFILE=${VERSION}_${DB}_protein_index.csv
CSVFILE_SORTED=${VERSION}_${DB}_protein_index_sorted.csv
REPFILE=${VERSION}_${DB}_protein_sharing.csv
REPLICAS=${VERSION}_${DB}_protein_replicas_ccdf.dat

if test ! -f $CSVFILE_SORTED
then
	if test ! -f $CSVFILE
	then
		echo "File $CSVFILE is missing.  Create it with ./2-prepareData.sh"
		exit
	fi
#
#	Sort the index on increasing length of protein sequence.
#
	sort -t"," --key=4 $CSVFILE -n -T $TEMPDIR | uniq -u				> $CSVFILE_SORTED
	rm -f $CSVFILE
else
	echo "File $CSVFILE_SORTED already exists.  To recreate, delete it and rerun $0.  Continuing ..."
fi
#
#	Find all the shared proteins.
#
#	Format is <length>,*-**** (number of kingdoms),<sequence>,<kingdom/species strings>,<count>,<protein name>
#
#	Create the whole thing.
#
if test ! -f $REPFILE
then
	./replicasInSpecies.pl -csvfile $CSVFILE_SORTED -repfile $REPFILE
else
	echo "File $REPFILE already exists.  To recreate, delete it and re-run $0.  Continuing ..."
fi
#
#	Create the ccdf for the replica occurrence.  We get rid of the first line with
#	tail because that count might be turned off in replicasInSpecies.pl.
#	Note that we include the zeroth value by specifying normalise ccdf0.
#
#	We do this for each individual DL+V.
#--------
echo "Creating Re-use distribution for Archaea ..."
cat $REPFILE | grep ",ARCHAEA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cp	$REPLICAS		archaea_replicas.dat

cat	protein_replicas_ccdf.gnu	\
	| sed 's/VVVV/'"${VERSION}"'/g' \
	| sed 's/DDDD/'"${DB}"'/g' \
	| sed 's/TTTT/ARCHAEA/g'						> temp$$.gnu
gnuplot	temp$$.gnu
mv	${VERSION}_${DB}_protein_replicas_ccdf.eps			Fig5.eps
convert	-density 300 Fig5.eps Fig5.png
#--------
echo "Creating Re-use distribution for Bacteria ..."
cat $REPFILE | grep ",BACTERIA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cp	$REPLICAS		bacteria_replicas.dat

cat	protein_replicas_ccdf.gnu	\
	| sed 's/VVVV/'"${VERSION}"'/g' \
	| sed 's/DDDD/'"${DB}"'/g' \
	| sed 's/TTTT/BACTERIA/g'					> temp$$.gnu
gnuplot	temp$$.gnu
mv	${VERSION}_${DB}_protein_replicas_ccdf.eps			Fig6.eps
convert	-density 300 Fig6.eps Fig6.png
#--------
echo "Creating Re-use distribution for Eukaryota ..."
cat $REPFILE | grep ",EUKARYOTA:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cp	$REPLICAS		eukaryota_replicas.dat

cat	protein_replicas_ccdf.gnu	\
	| sed 's/VVVV/'"${VERSION}"'/g' \
	| sed 's/DDDD/'"${DB}"'/g' \
	| sed 's/TTTT/EUKARYOTA/g'					> temp$$.gnu
gnuplot	temp$$.gnu
mv	${VERSION}_${DB}_protein_replicas_ccdf.eps			Fig7.eps
convert	-density 300 Fig7.eps Fig7.png
#--------
echo "Creating Re-use distribution for Viruses ..."
cat $REPFILE | grep ",VIRUSES:" | awk '{FS=","}{print $5;}' | sort -n | uniq -c | tail -n +2 \
	| ./normalise ccdf            > $REPLICAS
cp	$REPLICAS		viruses_replicas.dat

cat	protein_replicas_ccdf.gnu	\
	| sed 's/VVVV/'"${VERSION}"'/g' \
	| sed 's/DDDD/'"${DB}"'/g' \
	| sed 's/TTTT/VIRUSES/g'						> temp$$.gnu
gnuplot	temp$$.gnu
mv	${VERSION}_${DB}_protein_replicas_ccdf.eps			Fig8.eps
convert	-density 300 Fig8.eps Fig8.png
#--------
#	Clean up.
#
rm	-f temp$$.gnu
