#!/bin/sh
#	Produce Congeneric (VGT) and Other (HGT+Unknown) categories for each domain of life and altogether.
#
VERSION=21-03
DB=trembl

CSVFILE_SORTED=${VERSION}_${DB}_protein_index_sorted.csv
#
#	Columns in REPFILE
#
#	Length,kings,seq,tuples,count,counth,countv,countu
#
REPFILE=${VERSION}_${DB}_protein_sharing.csv

if test ! -f $REPFILE
then
	if test ! -f $CSVFILE_SORTED
	then
		echo "File $CSVFILE_SORTED does not exist"
		exit
	else
		./replicasInSpecies.pl -csvfile $CSVFILE_SORTED -repfile $REPFILE
	fi
else
	echo "File $REPFILE already exists.  To recreate, delete it and re-run $0.  Continuing ..."
fi
#
#	co = congeneric/other.
#
REPLICAS=${VERSION}_${DB}_protein_replicas_ccdf_co.dat
#
#	We only go through the protein file once.
#
for domain in BACTERIA ALL
do
#
#	The format of the DATFILE is 
#	<multiplicity>,<count_hgt>,<count_vgt>,<count_unknown>
#
#	The counts are calculated as follows:
#		Within a group of identical proteins, if all the same genus, its VGT.
#		If different genera, then count the genera to give HGT.  Its unknown if
#		there is no obvious genus.
#
	DATFILE=${VERSION}_${DB}_${domain}_gt.dat
	if test -f ${DATFILE}
	then
		echo "Summary file ${DATFILE} already exists and will be used.  Remove to re-creat.  Continuing ..."
	else
		if test "$domain" = "ALL"
		then
			cat $REPFILE | awk '{FS=","}{printf "%d,%d,%d,%d\n", $5, $6, $7, $8;}' > ${DATFILE}
		else
			cat $REPFILE | sed -n '/,'"${domain}"'/p' | awk '{FS=","}{printf "%d,%d,%d,%d\n", $5, $6, $7, $8;}' \
				> ${DATFILE}
		fi
	fi

	rm 	-f $REPLICAS

	cat $DATFILE | awk '{FS=","}{if ($3 > 0) print $3;}' | sort -n | uniq -c | tail -n +2 \
		| ./normalise ccdf	>> $REPLICAS
	cat $DATFILE | awk '{FS=","}{if ($2+$4 > 0) print $2+$4;}' | sort -n | uniq -c | tail -n +2 \
		| ./normalise ccdf	>> $REPLICAS

	cat  protein_replicas_ccdf_co.gnu	\
		| sed 's/VVVV/'"${VERSION}"'/g' \
		| sed 's/DDDD/'"${DB}"'/g' \
		| sed 's/TTTT/'"${domain}"'/g'					> temp$$.gnu
	gnuplot	temp$$.gnu
	rm -f temp$$.gnu

	mv	${VERSION}_${DB}_protein_replicas_ccdf_co.eps	${domain}_protein_replicas_ccdf_co.eps
done

mv	ALL_protein_replicas_ccdf_co.eps		Fig9.eps
mv	BACTERIA_protein_replicas_ccdf_co.eps	Fig10.eps

convert	-density 300 Fig9.eps	Fig9.png
convert	-density 300 Fig10.eps	Fig10.png
