#
#	This R script merges together the various contributions of the domains of life and viruses
#	to the overall multiplicity.
#
archaea		<- read.table("21-03_trembl_protein_ccdf_ARCHAEA.dat",header=FALSE)
bacteria		<- read.table("21-03_trembl_protein_ccdf_BACTERIA.dat",header=FALSE)
eukaryota		<- read.table("21-03_trembl_protein_ccdf_EUKARYOTA.dat",header=FALSE)
viruses		<- read.table("21-03_trembl_protein_ccdf_VIRUSES.dat",header=FALSE)
#
#	These data have missing bins.  V1 will be the bin numbers present  and V2 their values.
#	We must interpolate these first.  Linear should be good enough as missing bins do not
#	occur until things are flattening out nicely.
#
vec1 		<- c(1:10000)
vec2 		<- vector()

model		<- lm( V2 ~ V1, data = archaea)
for(i in 1:max(vec1))	{
	y_new	<- approx(archaea$V1, archaea$V2, xout=i)
	vec2[i]	<- y_new$y
}
#
#	After this, there will be NA outside of the interpolation range.  Replace with 0.
#
vec2[is.na(vec2)]    <- 0

archaea_vec1		<- vec1
archaea_vec2		<- vec2

model		<- lm( V2 ~ V1, data = bacteria)
for(i in 1:max(vec1))	{
	y_new	<- approx(bacteria$V1, bacteria$V2, xout=i)
	vec2[i]	<- y_new$y
}
#
#	After this, there will be NA outside of the interpolation range.  Replace with 0.
#
vec2[is.na(vec2)]    <- 0

bacteria_vec1		<- vec1
bacteria_vec2		<- vec2

model		<- lm( V2 ~ V1, data = eukaryota)
for(i in 1:max(vec1))	{
	y_new	<- approx(eukaryota$V1, eukaryota$V2, xout=i)
	vec2[i]	<- y_new$y
}
#
#	After this, there will be NA outside of the interpolation range.  Replace with 0.
#
vec2[is.na(vec2)]    <- 0

eukaryota_vec1		<- vec1
eukaryota_vec2		<- vec2

model		<- lm( V2 ~ V1, data = viruses)
for(i in 1:max(vec1))	{
	y_new	<- approx(viruses$V1, viruses$V2, xout=i)
	vec2[i]	<- y_new$y
}
#
#	After this, there will be NA outside of the interpolation range.  Replace with 0.
#
vec2[is.na(vec2)]    <- 0

viruses_vec1		<- vec1
viruses_vec2		<- vec2
#
#	We now have re-interpolated functions for each domain.  Calculate the percentages.
#
totalprot			<- vector()
for(i in 1:max(vec1))    {
	totalprot[i]	<- archaea_vec2[i] + bacteria_vec2[i] + eukaryota_vec2[i] + viruses_vec2[i]
}
#
#	Normalise to percentage.
#
for(i in 1:max(vec1))    {
	archaea_vec2[i]	<- 100 * archaea_vec2[i] / totalprot[i]
	bacteria_vec2[i]	<- 100 * bacteria_vec2[i] / totalprot[i]
	eukaryota_vec2[i]	<- 100 * eukaryota_vec2[i] / totalprot[i]
	viruses_vec2[i]	<- 100 * viruses_vec2[i] / totalprot[i]
}

postscript(file = "21-03_percentageMultiplicity.eps", horizontal = FALSE)
plot(vec1,eukaryota_vec2,col=1,xlab='multiplicity',ylab='Percentage')
lines(vec1,viruses_vec2,col=2)
lines(vec1,bacteria_vec2,col=3)
lines(vec1,archaea_vec2,col=4)
legend(x = "topright", legend = c("eukaryota","viruses","bactera","archaea"),col=c(1,2,3,4),lwd=2)
dev.off()

postscript(file = "21-03_percentageMultiplicity_mult1000.eps", horizontal = FALSE)
plot(vec1,eukaryota_vec2,xlim=c(0,1000),col=1,xlab='multiplicity',ylab='Percentage')
lines(vec1,viruses_vec2,col=2)
lines(vec1,bacteria_vec2,col=3)
lines(vec1,archaea_vec2,col=4)
legend(x = "topright", legend = c("eukaryota","viruses","bactera","archaea"),col=c(1,2,3,4),lwd=2)
dev.off()
